import { Plugin } from "esbuild";
/**
 * GLSL plugin options.
 */
export interface GLSLOptions {
    /**
     * Enables or disables shader minification.
     *
     * Default is `false`.
     */
    minify?: boolean;
    /**
     * Enables or disables shader include resolution.
     * When enabled, shaders can be included with the custom `#include "path"` directive.
     *
     * Default is `true`.
     */
    resolveIncludes?: boolean;
}
/**
 * An options wrapper function that returns the GLSL plugin.
 *
 * @param options The options.
 * @return The plugin.
 */
declare function glsl({ minify, resolveIncludes }?: GLSLOptions): Plugin;
export { glsl, glsl as default };
